local player = {}
local image = love.graphics.newImage("_assets/single.png")

function player:init()
    self.l = 10
    self.t = 10
    self.w = 25
    self.h = 96
    self.vx = 0
    self.vy = 0
    self.sprite = image
    self.speed = 80
    self.runAccel = 500
    self.brakeAccel = 2000
    self.jumpVelocity = 600
    self.isJumpingOrFlying = false
    self.jumpMeter = 0
    self.canJump = true
    self.onGround = false
end

function player:getCenter()
    return self.l + self.w / 2, self.t + self.h / 2
end

function player:draw()
    love.graphics.draw(self.sprite, self.l, self.t)
end

function player:drawHitbox()
    love.graphics.setColor(255, 0, 255, 70)
    love.graphics.rectangle("fill", self.l, self.t, self.w, self.h)
    love.graphics.setColor(255, 0, 255)
    love.graphics.rectangle("line", self.l, self.t, self.w, self.h)
    love.graphics.setColor(255, 255, 255)
end

function player:update(dt)
    local vx, vy = self.vx, self.vy

    if love.keyboard.isDown("a") then
        vx = vx - dt * (vx > 0 and self.brakeAccel or self.runAccel)
    elseif love.keyboard.isDown("d") then
        vx = vx + dt * (vx < 0 and self.brakeAccel or self.runAccel)
    else
        local brake = dt * (vx < 0 and self.brakeAccel or -self.brakeAccel)
        if math.abs(brake) > math.abs(vx) then
            vx = 0
        else
            vx = vx + brake
        end
    end

    if love.keyboard.isDown("w") and self.isJumpingOrFlying and self.canJump then
        if self.jumpMeter > -5000 then
            vy = -self.jumpVelocity
            self.jumpMeter = self.jumpMeter + vy
            self.jumpVelocity = self.jumpVelocity * 0.2
        end
    end

    self.jumpVelocity = 600
    self.vx, self.vy = vx, vy
end

function player:changeVelocityByCollisionNormal(nx, ny, bounciness)
    bounciness = bounciness or 0
    local vx, vy = self.vx, self.vy

    if (nx < 0 and vx > 0) or (nx > 0 and vx < 0) then
        vx = -vx * bounciness
    end

    if (ny < 0 and vy > 0) or (ny > 0 and vy < 0) then
        vy = -vy * bounciness
    end

    self.vx, self.vy = vx, vy
end

function player:checkIfOnGround(ny)
    if ny < 0 then
        self.onGround = true
        self.isJumpingOrFlying = false
        self.jumpMeter = 0
        self.canJump = true
    end
end

return player